@@ -20,6 +20,8 @@ import beaker.ext.memcached as memcached
 import beaker.ext.database as database
 import beaker.ext.sqla as sqla
 import beaker.ext.google as google
+import beaker.ext.mongodb as mongodb
+import beaker.ext.redisnm as redisnm
 from functools import wraps
 
 # Initialize the cache region dict
@@ -116,14 +118,16 @@ class _backends(object):
 
 # Initialize the basic available backends
 clsmap = _backends({
-          'memory': container.MemoryNamespaceManager,
-          'dbm': container.DBMNamespaceManager,
-          'file': container.FileNamespaceManager,
-          'ext:memcached': memcached.MemcachedNamespaceManager,
-          'ext:database': database.DatabaseNamespaceManager,
-          'ext:sqla': sqla.SqlaNamespaceManager,
-          'ext:google': google.GoogleNamespaceManager,
-          })
+    'memory': container.MemoryNamespaceManager,
+    'dbm': container.DBMNamespaceManager,
+    'file': container.FileNamespaceManager,
+    'ext:memcached': memcached.MemcachedNamespaceManager,
+    'ext:database': database.DatabaseNamespaceManager,
+    'ext:sqla': sqla.SqlaNamespaceManager,
+    'ext:google': google.GoogleNamespaceManager,
+    'ext:mongodb': mongodb.MongoNamespaceManager,
+    'ext:redis': redisnm.RedisNamespaceManager
+})
 
 
 def cache_region(region, *args):
@@ -172,7 +176,7 @@ def cache_region(region, *args):
     :param region: String name of the region corresponding to the desired
       caching arguments, established in :attr:`.cache_regions`.
 
-    :param \*args: Optional ``str()``-compatible arguments which will uniquely
+    :param *args: Optional ``str()``-compatible arguments which will uniquely
       identify the key used by this decorated function, in addition
       to the positional arguments passed to the function itself at call time.
       This is recommended as it is needed to distinguish between any two functions
@@ -591,6 +595,8 @@ def _cache_decorate(deco_args, manager, options, region):
 
             def go():
                 return func(*args, **kwargs)
+            # save org function name
+            go.__name__ = '_cached_%s' % (func.__name__,)
 
             return cache[0].get_value(cache_key, createfunc=go)
         cached._arg_namespace = namespace
