@@ -1,4 +1,9 @@
 """Beaker utilities"""
+import hashlib
+import socket
+
+import binascii
+
 from ._compat import PY2, string_type, unicode_text, NoneType, dictkeyslist, im_class, im_func, pickle, func_signature, \
     default_im_func
 
@@ -45,7 +50,7 @@ def skip_if(predicate, reason=None):
     """Skip a test if predicate is true."""
     reason = reason or predicate.__name__
 
-    from nose import SkipTest
+    from unittest import SkipTest
 
     def decorate(fn):
         fn_name = fn.__name__
@@ -304,6 +309,8 @@ def coerce_session_params(params):
         ('secure', (bool, NoneType), "Session secure must be a boolean."),
         ('httponly', (bool, NoneType), "Session httponly must be a boolean."),
         ('timeout', (int, NoneType), "Session timeout must be an integer."),
+        ('save_accessed_time', (bool, NoneType),
+         "Session save_accessed_time must be a boolean (defaults to true)."),
         ('auto', (bool, NoneType), "Session is created if accessed."),
         ('webtest_varname', (str, NoneType), "Session varname must be a string."),
         ('data_serializer', (str,), "data_serializer must be a string.")
@@ -313,6 +320,10 @@ def coerce_session_params(params):
     if cookie_expires and isinstance(cookie_expires, int) and \
        not isinstance(cookie_expires, bool):
         opts['cookie_expires'] = timedelta(seconds=cookie_expires)
+
+    if opts.get('timeout') is not None and not opts.get('save_accessed_time', True):
+        raise Exception("save_accessed_time must be true to use timeout")
+
     return opts
 
 
@@ -325,7 +336,7 @@ def coerce_cache_params(params):
         ('expire', (int, NoneType),
          "expire must be an integer representing how many seconds the cache is valid for"),
         ('regions', (list, tuple, NoneType),
-         "Regions must be a comma seperated list of valid regions"),
+         "Regions must be a comma separated list of valid regions"),
         ('key_length', (int, NoneType),
          "key_length must be an integer which indicates the longest a key can be before hashing"),
     ]
@@ -442,15 +453,55 @@ def func_namespace(func):
         return '%s|%s' % (inspect.getsourcefile(func), func.__name__)
 
 
+class PickleSerializer(object):
+    def loads(self, data_string):
+        return pickle.loads(data_string)
+
+    def dumps(self, data):
+        return pickle.dumps(data, 2)
+
+
+class JsonSerializer(object):
+    def loads(self, data_string):
+        return json.loads(zlib.decompress(data_string).decode('utf-8'))
+
+    def dumps(self, data):
+        return zlib.compress(json.dumps(data).encode('utf-8'))
+
+
 def serialize(data, method):
     if method == 'json':
-        return zlib.compress(json.dumps(data).encode('utf-8'))
+        serializer = JsonSerializer()
     else:
-        return pickle.dumps(data, 2)
+        serializer = PickleSerializer()
+    return serializer.dumps(data)
 
 
 def deserialize(data_string, method):
     if method == 'json':
-        return json.loads(zlib.decompress(data_string).decode('utf-8'))
+        serializer = JsonSerializer()
     else:
-        return pickle.loads(data_string)
+        serializer = PickleSerializer()
+    return serializer.loads(data_string)
+
+
+def machine_identifier():
+    machine_hash = hashlib.md5()
+    if not PY2:
+        machine_hash.update(socket.gethostname().encode())
+    else:
+        machine_hash.update(socket.gethostname())
+    return binascii.hexlify(machine_hash.digest()[0:3]).decode('ascii')
+
+
+def safe_write (filepath, contents):
+    if os.name == 'posix':
+        tempname = '%s.temp' % (filepath)
+        fh = open(tempname, 'wb')
+        fh.write(contents)
+        fh.close()
+        os.rename(tempname, filepath)
+    else:
+        fh = open(filepath, 'wb')
+        fh.write(contents)
+        fh.close()
